@@ -1,7 +1,7 @@
 package Perinci::CmdLine::Inline;
 
 our $DATE = '2017-01-12'; # DATE
-our $VERSION = '0.45'; # VERSION
+our $VERSION = '0.46'; # VERSION
 
 use 5.010001;
 use strict;
@@ -739,8 +739,6 @@ Currently it only supports a subset of features compared to other
 * Only support local Riap URL (e.g. `/Foo/bar`, not
   `http://example.org/Foo/bar`);
 
-* No configuration file support yet.
-
 As an alternative to this module, if you are looking to reduce dependencies, you
 might also want to try using `depak` to fatpack/datapack your
 <pm:Perinci::CmdLine::Lite>-based script.
@@ -1447,7 +1445,7 @@ Perinci::CmdLine::Inline - Generate inline Perinci::CmdLine CLI script
 
 =head1 VERSION
 
-This document describes version 0.45 of Perinci::CmdLine::Inline (from Perl distribution Perinci-CmdLine-Inline), released on 2017-01-12.
+This document describes version 0.46 of Perinci::CmdLine::Inline (from Perl distribution Perinci-CmdLine-Inline), released on 2017-01-12.
 
 =head1 SYNOPSIS
 
@@ -1527,8 +1525,6 @@ C<Perinci::CmdLine::*> implementations:
 =item * Only support local Riap URL (e.g. C</Foo/bar>, not
 CLL<http://example.org/Foo/bar>);
 
-=item * No configuration file support yet.
-
 =back
 
 As an alternative to this module, if you are looking to reduce dependencies, you
